'use strict';

var _get = require('babel-runtime/helpers/get')['default'];

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _objectWithoutProperties = require('babel-runtime/helpers/object-without-properties')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactPureRenderFunction = require('react-pure-render/function');

var _reactPureRenderFunction2 = _interopRequireDefault(_reactPureRenderFunction);

var _Mask = require('./Mask');

var _Mask2 = _interopRequireDefault(_Mask);

var _InputPopup = require('./InputPopup');

var _InputPopup2 = _interopRequireDefault(_InputPopup);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _reactDatePicker = require('react-date-picker');

var _reactDatePicker2 = _interopRequireDefault(_reactDatePicker);

var _jss = require('jss');

var _jssNested = require('jss-nested');

var _jssNested2 = _interopRequireDefault(_jssNested);

var _jssVendorPrefixer = require('jss-vendor-prefixer');

var _jssVendorPrefixer2 = _interopRequireDefault(_jssVendorPrefixer);

var jss = (0, _jss.create)();
jss.use((0, _jssNested2['default'])());
jss.use((0, _jssVendorPrefixer2['default'])());

var VALIDATORS = {
  YYYY: function YYYY() {
    return false;
  },
  MM: function MM(val) {
    return parseInt(val, 10) > 12;
  },
  DD: function DD(val) {
    return parseInt(val, 10) > 31;
  }
};

function parseDate(value, pattern) {
  return (0, _moment2['default'])(value, pattern).format('YYYY-MM-DD');
}

var DatePicker = (function (_Component) {
  _inherits(DatePicker, _Component);

  function DatePicker() {
    var _this = this;

    _classCallCheck(this, DatePicker);

    _get(Object.getPrototypeOf(DatePicker.prototype), 'constructor', this).apply(this, arguments);

    this.shouldComponentUpdate = _reactPureRenderFunction2['default'];

    this.renderPopup = function (popupClassName, popupStyle, isActive, popupShown) {
      var _props = _this.props;
      var onRenderCalendar = _props.onRenderCalendar;
      var value = _props.value;
      var pattern = _props.pattern;

      return onRenderCalendar(popupClassName, popupStyle, value, pattern, isActive, popupShown);
    };

    this.handleValidate = function (value, processedValue) {
      var _props2 = _this.props;
      var pattern = _props2.pattern;
      var emptyChar = _props2.emptyChar;

      var re = RegExp(emptyChar, 'g');

      return _Object$keys(VALIDATORS).some(function (format) {
        var pos = pattern.indexOf(format);
        if (pos !== -1) {
          var _value = processedValue.substr(pos, format.length).replace(re, '');
          return VALIDATORS[format](_value);
        }
      });
    };
  }

  _createClass(DatePicker, [{
    key: 'render',
    value: function render() {
      var _props3 = this.props;
      var pattern = _props3.pattern;
      var children = _props3.children;
      var value = _props3.value;
      var defaultValue = _props3.defaultValue;
      var onChange = _props3.onChange;

      var props = _objectWithoutProperties(_props3, ['pattern', 'children', 'value', 'defaultValue', 'onChange']);

      return _react2['default'].createElement(
        _Mask2['default'],
        { pattern: pattern.replace(/[dDmMyY]/g, '0'),
          value: value,
          defaultValue: defaultValue,
          onValidate: this.handleValidate,
          onChange: onChange },
        _react2['default'].createElement(
          _InputPopup2['default'],
          _extends({}, props, { onRenderPopup: this.renderPopup }),
          children
        )
      );
    }
  }], [{
    key: 'propTypes',
    value: {},
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      pattern: 'DD/MM/YYYY',
      onRenderCalendar: function onRenderCalendar(className, style, value, pattern, isActive, popupShown) {
        return popupShown && _react2['default'].createElement(
          'div',
          { className: className, style: style },
          _react2['default'].createElement(_reactDatePicker2['default'], { date: parseDate(value, pattern),
            className: sheet.classes.datePicker })
        );
      }
    },
    enumerable: true
  }]);

  return DatePicker;
})(_react.Component);

exports['default'] = DatePicker;

var sheet = jss.createStyleSheet({
  datePicker: {
    display: 'flex',
    'flex-direction': 'column',
    flex: '1 0 auto',
    'box-sizing': 'border-box',
    width: '28rem',

    '& *': {
      'box-sizing': 'border-box'
    },

    '& .dp-header': {
      background: '#f0f0f0',
      'border-bottom': '1px solid #CCCCCC',
      '& .dp-cell': {
        padding: '0.5rem',
        color: '#000'
      }
    },

    '& .dp-footer': {
      display: 'flex',
      'flex-direction': 'row',
      'justify-content': 'space-around',
      padding: '0.5rem'
    },

    '& .dp-body': {
      display: 'flex',
      'flex-direction': 'column',
      flex: 1
    },

    '& .dp-week-day-names': {
      color: '#000'
    },

    '& .dp-prev, & .dp-next': {
      color: '#AAA'
    },

    '& .dp-table': {
      width: '100%',
      height: '100%',
      display: 'flex',
      'flex-direction': 'column',
      flex: 1
    },

    '& .dp-row': {
      display: 'flex',
      'flex-direction': 'row',
      flex: 1
    },

    '& .dp-cell': {
      display: 'flex',
      'align-items': 'center',
      'justify-content': 'center',
      flex: 1,
      padding: '0.5rem'
    },

    '& .dp-nav-table': {
      width: '100%',
      display: 'flex',
      'flex-direction': 'row',
      flex: 1,

      '& .dp-cell': {
        flex: 7
      },

      '& .dp-nav-cell': {
        flex: 1,
        cursor: 'pointer'
      },

      '& .dp-nav-cell:hover': {
        'background-color': '#EEE'
      }
    }
  }
}).attach();
module.exports = exports['default'];